summaryrefslogtreecommitdiffstats
path: root/chrome/browser/chrome_plugin_unittest.cc
diff options
context:
space:
mode:
authortfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-01-11 00:13:24 +0000
committertfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-01-11 00:13:24 +0000
commitcbe04ef2b51e5a666869235e2a49714057e523da (patch)
tree1baf21d471361eb078479bad74d7822f24a482bd /chrome/browser/chrome_plugin_unittest.cc
parent9e790bdb7aabd7849243158d7095fb79dc26262c (diff)
downloadchromium_src-cbe04ef2b51e5a666869235e2a49714057e523da.zip
chromium_src-cbe04ef2b51e5a666869235e2a49714057e523da.tar.gz
chromium_src-cbe04ef2b51e5a666869235e2a49714057e523da.tar.bz2
net: Remove typedef net::URLRequestTestJob URLRequestTestJob;
BUG=64263 TEST=compiled locally, trybots Review URL: http://codereview.chromium.org/6202002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@70966 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/chrome_plugin_unittest.cc')
-rw-r--r--chrome/browser/chrome_plugin_unittest.cc24
1 files changed, 12 insertions, 12 deletions
diff --git a/chrome/browser/chrome_plugin_unittest.cc b/chrome/browser/chrome_plugin_unittest.cc
index 9322678..93dc18d 100644
--- a/chrome/browser/chrome_plugin_unittest.cc
+++ b/chrome/browser/chrome_plugin_unittest.cc
@@ -1,4 +1,4 @@
-// Copyright (c) 2006-2008 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
// Tests exercising the Chrome Plugin API.
@@ -74,7 +74,7 @@ class ChromePluginTest : public testing::Test,
virtual void SetUp() {
LoadPlugin();
net::URLRequest::RegisterProtocolFactory("test",
- &URLRequestTestJob::Factory);
+ &net::URLRequestTestJob::Factory);
// We need to setup a default request context in order to issue HTTP
// requests.
@@ -126,10 +126,10 @@ static void STDCALL CPT_Complete(CPRequest* request, bool success,
EXPECT_TRUE(success);
EXPECT_EQ(200, headers->response_code());
- if (url == URLRequestTestJob::test_url_1()) {
- EXPECT_EQ(URLRequestTestJob::test_data_1(), body);
- } else if (url == URLRequestTestJob::test_url_2()) {
- EXPECT_EQ(URLRequestTestJob::test_data_2(), body);
+ if (url == net::URLRequestTestJob::test_url_1()) {
+ EXPECT_EQ(net::URLRequestTestJob::test_data_1(), body);
+ } else if (url == net::URLRequestTestJob::test_url_2()) {
+ EXPECT_EQ(net::URLRequestTestJob::test_data_2(), body);
} else if (url.spec().find("echo") != std::string::npos) {
EXPECT_EQ(kChromeTestPluginPostData, body);
}
@@ -249,7 +249,7 @@ TEST_F(ChromePluginTest, UnregisterIntercept) {
}
static void ProcessAllPendingMessages() {
- while (URLRequestTestJob::ProcessOnePendingMessage());
+ while (net::URLRequestTestJob::ProcessOnePendingMessage());
}
// Tests that the plugin can issue a GET request and receives the data when
@@ -257,10 +257,10 @@ static void ProcessAllPendingMessages() {
TEST_F(ChromePluginTest, CanMakeGETRequestSync) {
// test_url_1 has a synchronous response
EXPECT_EQ(CPERR_SUCCESS, test_funcs_.test_make_request(
- "GET", URLRequestTestJob::test_url_1()));
+ "GET", net::URLRequestTestJob::test_url_1()));
// Note: we must add this task after we make the request, so that
// URLRequestTestJob's StartAsync task is added and run first.
MessageLoop::current()->PostTask(FROM_HERE,
NewRunnableFunction(&ProcessAllPendingMessages));
MessageLoop::current()->Run();
@@ -271,10 +271,10 @@ TEST_F(ChromePluginTest, CanMakeGETRequestSync) {
TEST_F(ChromePluginTest, CanMakeGETRequestAsync) {
// test_url_2 has an asynchronous response
EXPECT_EQ(CPERR_SUCCESS, test_funcs_.test_make_request(
- "GET", URLRequestTestJob::test_url_2()));
+ "GET", net::URLRequestTestJob::test_url_2()));
// Note: we must add this task after we make the request, so that
// URLRequestTestJob's StartAsync task is added and run first.
MessageLoop::current()->PostTask(FROM_HERE,
NewRunnableFunction(&ProcessAllPendingMessages));
MessageLoop::current()->Run();
@@ -290,7 +290,7 @@ TEST_F(ChromePluginTest, CanMakePOSTRequest) {
EXPECT_EQ(CPERR_SUCCESS, test_funcs_.test_make_request("POST", url));
// Note: we must add this task after we make the request, so that
// URLRequestTestJob's StartAsync task is added and run first.
MessageLoop::current()->PostTask(FROM_HERE,
NewRunnableFunction(&ProcessAllPendingMessages));
MessageLoop::current()->Run();
@@ -257,10 +257,10 @@ static void ProcessAllPendingMessages() {
// Note: we must add this task after we make the request, so that
- // URLRequestTestJob's StartAsync task is added and run first.
+ // net::URLRequestTestJob's StartAsync task is added and run first.
MessageLoop::current()->PostTask(FROM_HERE,
NewRunnableFunction(&ProcessAllPendingMessages));
@@ -271,10 +271,10 @@ TEST_F(ChromePluginTest, CanMakeGETRequestSync) {
// Note: we must add this task after we make the request, so that
- // URLRequestTestJob's StartAsync task is added and run first.
+ // net::URLRequestTestJob's StartAsync task is added and run first.
MessageLoop::current()->PostTask(FROM_HERE,
NewRunnableFunction(&ProcessAllPendingMessages));
@@ -290,7 +290,7 @@ TEST_F(ChromePluginTest, CanMakePOSTRequest) {
EXPECT_EQ(CPERR_SUCCESS, test_funcs_.test_make_request("POST", url));
// Note: we must add this task after we make the request, so that
- // URLRequestTestJob's StartAsync task is added and run first.
+ // net::URLRequestTestJob's StartAsync task is added and run first.
MessageLoop::current()->PostTask(FROM_HERE,
NewRunnableFunction(&ProcessAllPendingMessages));